@@ -250,12 +250,13 @@ cb_end_process_button_pressed (GtkButton *button, gpointer data)
 static void change_settings_color(GSettings *settings, const char *key,
                    GSMColorButton *cp)
 {
-    GdkColor c;
-    char color[24]; /* color should be 1 + 3*4 + 1 = 15 chars -> 24 */
+    GdkRGBA c;
+    char *color;
 
     gsm_color_button_get_color(cp, &c);
-    g_snprintf(color, sizeof color, "#%04x%04x%04x", c.red, c.green, c.blue);
+    color = gdk_rgba_to_string (&c);
     g_settings_set_string (settings, key, color);
+    g_free (color);
 }
 
 
@@ -450,7 +451,7 @@ gint
 cb_user_refresh (GtkAction*, gpointer data)
 {
     ProcData * const procdata = static_cast<ProcData*>(data);
-    proctable_update_all(procdata);
+    proctable_update (procdata);
     return FALSE;
 }
 
@@ -461,7 +462,7 @@ cb_timeout (gpointer data)
     ProcData * const procdata = static_cast<ProcData*>(data);
     guint new_interval;
 
-    proctable_update_all (procdata);
+    proctable_update (procdata);
 
     if (procdata->smooth_refresh->get(new_interval))
     {
